@@ -250,11 +250,20 @@ popup_cup_timer (TeatimePopup *popup)
   return TRUE;  
 }
 
-static void
-stop_sound_thread (GstElement *element,
-                   gpointer data)
+static gboolean
+bus_callback (GstBus     *bus,
+              GstMessage *msg,
+              gpointer    data)
 {
-  gst_element_set_state (GST_ELEMENT (data), GST_STATE_NULL);
+  switch (GST_MESSAGE_TYPE (msg)) {
+    case GST_MESSAGE_ERROR:
+    case GST_MESSAGE_EOS:
+      gst_element_set_state (GST_ELEMENT (data), GST_STATE_READY);
+      break;
+    default:
+      break;
+  }
+  return TRUE;
 }
 
 static gint
@@ -273,29 +282,20 @@ timer(Teatime *teatime)
   if (teatime->timer_handle)
     gtk_timeout_remove (teatime->timer_handle);
   teatime_applet_redraw (teatime);
-  if (teatime->properties.play_sound && teatime->properties.sound)
-  {
-    audio_sink = gst_gconf_get_default_audio_sink ();
-    if (GST_IS_ELEMENT (audio_sink))
-    {
-      teatime->sound.thread = gst_thread_new ("pipe");
-      teatime->sound.input = gst_element_factory_make ("filesrc", "input");
-      g_signal_connect (G_OBJECT (teatime->sound.input), "eos",
-                        G_CALLBACK (stop_sound_thread), teatime->sound.thread);
-      teatime->sound.decoder = gst_element_factory_make ("spider", "decoder");
-      teatime->sound.output = audio_sink;
-      gst_bin_add_many (GST_BIN (teatime->sound.thread),
-                        teatime->sound.input,
-                        teatime->sound.decoder,
-                        teatime->sound.output, NULL);
-      gst_element_link_many (teatime->sound.input,
-                             teatime->sound.decoder,
-                             teatime->sound.output, NULL);   
-      g_object_set (G_OBJECT (teatime->sound.input), "location", teatime->properties.sound, NULL);
-      gst_element_set_state (teatime->sound.thread,  GST_STATE_PLAYING);
+  if (teatime->properties.play_sound && teatime->properties.sound && teatime->sound)
+  {    
+    gchar *uri = g_filename_to_uri (teatime->properties.sound, NULL, NULL);
+    GstState state = GST_STATE (teatime->sound);
+
+    if (state == GST_STATE_PLAYING || state == GST_STATE_PAUSED)
+      if (gst_element_set_state (teatime->sound, GST_STATE_READY) == GST_STATE_CHANGE_ASYNC)
+        gst_element_get_state (teatime->sound, NULL, NULL, GST_CLOCK_TIME_NONE);
+
+    if (uri) {
+      g_object_set (G_OBJECT (teatime->sound), "uri", uri, NULL);
+      g_free (uri);
+      gst_element_set_state (teatime->sound, GST_STATE_PLAYING);
     }
-    else
-      g_warning ("Could not get default audio sink from GConf");
   }
   if (!teatime->properties.popup)
     return FALSE;
@@ -352,8 +352,8 @@ display_about_dialog(BonoboUIComponent *uic,
   GError *error = NULL;
   static GtkWidget *about = NULL;
   const gchar *authors [] = {N_("Detlef Reichl\n\tdetlef ! reichl () gmx ! org"), NULL};
-  const gchar *website = "http://dr.dhis.org/teatime/index.rbx?r=2.6.0";
-  const gchar *website_label = N_("Visit the Teatime website\nhttp://dr.dhis.org/teatime/");
+  const gchar *website = "http://det.cable.nu/teatime/index.rbx?r=2.8.0";
+  const gchar *website_label = N_("Visit the Teatime website\nhttp://det.cable.nu/teatime/");
   
   if (about != NULL)
   {
@@ -369,7 +369,7 @@ display_about_dialog(BonoboUIComponent *uic,
   about = gtk_about_dialog_new ();
   gtk_about_dialog_set_name (GTK_ABOUT_DIALOG (about), _("Teatime"));
   gtk_about_dialog_set_version (GTK_ABOUT_DIALOG (about), VERSION);
-  gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (about), _("Copyright (C) 1998-2005 Detlef Reichl"));
+  gtk_about_dialog_set_copyright (GTK_ABOUT_DIALOG (about), _("Copyright (C) 1998-2007 Detlef Reichl"));
   gtk_about_dialog_set_comments (GTK_ABOUT_DIALOG (about), _("A\ntea-drawing-time-observer.\n"
                                                              "The most useful GNOME program ;-)"));
   gtk_about_dialog_set_website (GTK_ABOUT_DIALOG (about), website);
@@ -527,6 +527,9 @@ destroy (GtkWidget *applet, Teatime *teatime)
     if (teatime->cup_full_hl[i])
       g_object_unref (G_OBJECT (teatime->cup_full_hl[i]));
   }
+
+  if (teatime->sound)
+    gst_object_unref (GST_OBJECT (teatime->sound));
   
   g_free (teatime);
 }
@@ -618,7 +621,20 @@ teatime_applet_new (PanelApplet *applet)
   
   gdk_rgb_init();
 
-  gst_init(NULL, NULL);
+  gst_init (0, NULL);
+
+  teatime->sound = gst_element_factory_make ("playbin", "playbin");
+  if (teatime->sound) {
+      GstBus *bus;
+
+      g_object_set (G_OBJECT (teatime->sound), "video-sink", NULL, NULL);
+      g_object_set (G_OBJECT (teatime->sound), "vis-plugin", NULL, NULL);
+
+      bus = gst_pipeline_get_bus (GST_PIPELINE (teatime->sound));
+      gst_bus_add_watch (bus, bus_callback, teatime->sound);
+      gst_object_unref (bus);
+  } else
+    g_warning ("Could not initialize GStreamer");
   
   teatime_load_properties (teatime);
   teatime_image_loader_load_popup_images (teatime);
